@@ -20,6 +20,7 @@ from subprocess import Popen, PIPE
 class KeyZoneException(Exception):
     pass
 
+
 ########################################################################
 # class keyzone
 ########################################################################
@@ -33,19 +34,19 @@ class keyzone:
         if not name:
             return
 
-        if not czpath or not os.path.isfile(czpath) \
-                or not os.access(czpath, os.X_OK):
+        if not czpath or not os.path.isfile(czpath) or not os.access(czpath, os.X_OK):
             raise KeyZoneException('"named-compilezone" not found')
             return
 
         maxttl = keyttl = None
 
-        fp, _ = Popen([czpath, "-o", "-", name, filename],
-                      stdout=PIPE, stderr=PIPE).communicate()
+        fp, _ = Popen(
+            [czpath, "-o", "-", name, filename], stdout=PIPE, stderr=PIPE
+        ).communicate()
         for line in fp.splitlines():
             if type(line) is not str:
-                line = line.decode('ascii')
-            if re.search('^[:space:]*;', line):
+                line = line.decode("ascii")
+            if re.search("^[:space:]*;", line):
                 continue
             fields = line.split()
             if not maxttl or int(fields[1]) > maxttl:
